api.documents.v1.folder.test_helpers.folder_root package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.folder.test_helpers.folder_root package

## Submodules

## api.documents.v1.folder.test_helpers.folder_root.add_document module

`api.documents.v1.folder.test_helpers.folder_root.add_document.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/documents, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.add_document.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/documents, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.add_document.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/documents, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.add_document.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/documents, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.add_folder module

`api.documents.v1.folder.test_helpers.folder_root.add_folder.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.add_folder.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.add_folder.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.add_folder.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.browse_folder module

`api.documents.v1.folder.test_helpers.folder_root.browse_folder.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/content, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.browse_folder.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/content, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.browse_folder.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/content, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.browse_folder.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/content, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.delete_folder module

`api.documents.v1.folder.test_helpers.folder_root.delete_folder.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.delete_folder.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.delete_folder.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.delete_folder.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.get_current_user_root_folder module

`api.documents.v1.folder.test_helpers.folder_root.get_current_user_root_folder.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/root, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.get_current_user_root_folder.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/root, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.get_current_user_root_folder.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/root, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.get_current_user_root_folder.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/root, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.get_folder_meta_info_by_id module

`api.documents.v1.folder.test_helpers.folder_root.get_folder_meta_info_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.get_folder_meta_info_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.get_folder_meta_info_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.get_folder_meta_info_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.grant_folder_access module

`api.documents.v1.folder.test_helpers.folder_root.grant_folder_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.grant_folder_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.grant_folder_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.grant_folder_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.list_folder_access module

`api.documents.v1.folder.test_helpers.folder_root.list_folder_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.list_folder_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.list_folder_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.list_folder_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.revoke_folder_access module

`api.documents.v1.folder.test_helpers.folder_root.revoke_folder_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access/w+, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.revoke_folder_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access/w+, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.revoke_folder_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access/w+, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.revoke_folder_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access/w+, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.update_document_access_settings module

`api.documents.v1.folder.test_helpers.folder_root.update_document_access_settings.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.update_document_access_settings.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.update_document_access_settings.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.update_document_access_settings.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+/access, respond with HTTP 401

## api.documents.v1.folder.test_helpers.folder_root.update_folder module

`api.documents.v1.folder.test_helpers.folder_root.update_folder.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 403

`api.documents.v1.folder.test_helpers.folder_root.update_folder.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 404

`api.documents.v1.folder.test_helpers.folder_root.update_folder.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 200

`api.documents.v1.folder.test_helpers.folder_root.update_folder.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/folder/w+, respond with HTTP 401

## Module contents